pub struct ListKeysPaginatorItems(/* private fields */);Expand description
Flattened paginator for ListKeysPaginator
This is created with .items()
Implementations
Sourceimpl ListKeysPaginatorItems
impl ListKeysPaginatorItems
Sourcepub fn send(
self,
) -> PaginationStream<Result<KeyListEntry, SdkError<ListKeysError, HttpResponse>>>
pub fn send( self, ) -> PaginationStream<Result<KeyListEntry, SdkError<ListKeysError, HttpResponse>>>
Create the pagination stream
Note: No requests will be dispatched until the stream is used
(e.g. with the .next().await method).
To read the entirety of the paginator, use .collect::<Result<Vec<_>, _>().